==> v0.1.8.tar.gz: phetch/README.md <==
<!--
      /         /         /
 ___ (___  ___ (___  ___ (___
|   )|   )|___)|    |    |   )
|__/ |  / |__  |__  |__  |  /
|
--> <p align="center"> <img src="./img/logo.png"> </p>

`phetch` is a terminal client designed to help you quickly navigate
the gophersphere.

## features

- <1MB executable for linux and mac
- technicolor design (based on [GILD](https://github.com/dvkt/gild))
- no-nonsense keyboard navigation
- supports gopher searches, text and menu pages, and downloads
- save your favorite gopherholes with bookmarks
- opt-in history

## usage

    phetch                           launch and show start page
    phetch <gopher-url>              open gopher url
    phetch -r, --raw <gopher-url>    print raw gopher response
    phetch -h, --help                show this screen
    phetch -v, --version             show phetch version

    once you've launched phetch, use `ctrl-h` to view the on-line help.

## installation

binaries for linux, mac, and raspberry pi are available
at https://github.com/dvkt/phetch/releases:

- [phetch-v0.1.8-linux-x86_64.tar.gz][0]
- [phetch-v0.1.8-linux-armv7.tar.gz (RPi)][1]
- [phetch-v0.1.8-macos.zip][2]

just unzip/untar the `phetch` program into your $PATH and get going!

## development

    cargo run -- <gopher-url>

## screenies

![DOS Archive](./img/dos.png)

![Menu View](./img/menu-view.png)

![Text View](./img/text-view.png)

## todo

- [ ] fork+exec telnet: gopher://bitreich.org/1/lawn/bbs
- [ ] improve render() performance
- [ ] text views are menus when URLs are present (one per line max)
- [ ] Find Text in Text views
- [ ] TLS -- https://dataswamp.org/~solene/2019-03-07-gopher-server-tls.html
- [ ] ~/.config/phetch/phetch.conf

## bugs

- [ ] gopher://1436.ninja/1/twit.cgi ("iWritten and performed by Nathaniel" weirdness)
- [ ] screen flicker in win10 WSL
- [ ] NUM entry and Find entry shouldn't use same input buffer
- [ ] ctrl-z (suspend) doesn't work

## v1.0

- [ ] download new releases over gopher
- [ ] Changelog generation (for gopher and github)
- [ ] GIF screencast
- [ ] man page (small one)

## future features

- [ ] track binary size per release
- [ ] fuzzy find incremental search
- [ ] persistent history
- [ ] bookmarks: toggle instead of just prepending to the file
- [ ] bookmarks: save the title of the current page

[0]: https://github.com/dvkt/phetch/releases/download/v0.1.8/phetch-v0.1.8-linux-x86_64.tar.gz
[1]: https://github.com/dvkt/phetch/releases/download/v0.1.8/phetch-v0.1.8-linux-armv7.tar.gz
[2]: https://github.com/dvkt/phetch/releases/download/v0.1.8/phetch-v0.1.8-macos.zip

==> v0.1.10.tar.gz: phetch/README.md <==
<!--
      /         /         /
 ___ (___  ___ (___  ___ (___
|   )|   )|___)|    |    |   )
|__/ |  / |__  |__  |__  |  /
|
--> <p align="center"> <img src="./img/logo.png"> </p>

`phetch` is a terminal client designed to help you quickly navigate
the gophersphere.

## features

- <1MB executable for linux and mac
- technicolor design (based on [GILD](https://github.com/dvkt/gild))
- no-nonsense keyboard navigation
- supports gopher searches, text and menu pages, and downloads
- save your favorite gopherholes with bookmarks
- opt-in history

## usage

    phetch                           launch and show start page
    phetch <gopher-url>              open gopher url
    phetch -r, --raw <gopher-url>    print raw gopher response
    phetch -l, --local               connect to 127.0.0.1:7070
    phetch -h, --help                show this screen
    phetch -v, --version             show phetch version

    once you've launched phetch, use `ctrl-h` to view the on-line help.

## installation

binaries for linux, mac, and raspberry pi are available
at https://github.com/dvkt/phetch/releases:

- [phetch-v0.1.10-linux-x86_64.tar.gz][0]
- [phetch-v0.1.10-linux-armv7.tar.gz (RPi)][1]
- [phetch-v0.1.10-macos.zip][2]

just unzip/untar the `phetch` program into your $PATH and get going!

## updates

to check for new versions of `phetch`, you can use the on-line help
system (`ctrl-h`) or visit:

    gopher://phkt.io/1/phetch/latest

## development

    cargo run -- <gopher-url>

*pro-tip:* run a local gopher server on `127.0.0.1:7070` and start
phetch with `-l` or `--local` to quickly connect to it.

## screenies

![DOS Archive](./img/dos.png)

![Menu View](./img/menu-view.png)

![Text View](./img/text-view.png)

## todo

- [ ] fork+exec telnet: gopher://bitreich.org/1/lawn/bbs
- [ ] TLS -- https://dataswamp.org/~solene/2019-03-07-gopher-server-tls.html
- [ ] ~/.config/phetch/phetch.conf

## bugs

- [ ] gopher://1436.ninja/1/twit.cgi ("iWritten and performed by
  Nathaniel" weirdness) (kitty only)
- [ ] gopherpedia 'recent entries' weirdness (also kitty only)
- [ ] "stream did not contain valid UTF-8"  sdf.org/maps/
- [ ] ctrl-z (suspend) doesn't work
- [ ] gopher://alexschroeder.ch/2020-01-02_This_Gopher_Hole/menu

## v1.0

- [ ] check for updates over gopher
- [ ] Changelog generation (for gopher and github)
- [ ] GIF screencast
- [ ] man page (small one)

## future features

- [ ] track binary size per release
- [ ] text views are menus when URLs are present (one per line max)
- [ ] Find Text in Text views
- [ ] fuzzy find incremental search
- [ ] persistent history
- [ ] bookmarks: toggle instead of just prepending to the file
- [ ] bookmarks: save the title of the current page

[0]: https://github.com/dvkt/phetch/releases/download/v0.1.10/phetch-v0.1.10-linux-x86_64.tar.gz
[1]: https://github.com/dvkt/phetch/releases/download/v0.1.10/phetch-v0.1.10-linux-armv7.tar.gz
[2]: https://github.com/dvkt/phetch/releases/download/v0.1.10/phetch-v0.1.10-macos.zip
